@@ -60,29 +60,32 @@ class ZimbraBackend(django.contrib.auth.backends.ModelBackend):
     
     Users have to use their full E-Mail adress and Zimbra Passwort to log in.
     This obviously leads to an awful lot of trouble if the E-Mail adresses in your 
-    User Database are not unique.
+    User Database are not unique. It also gets in trouble if you have adresses which
+    are only destinguished by a dot. So 'mdornseif' 'm.dornseif' and 'mdo.rnseif' can't
+    coexist.
     
     The Backend creates a new entry in the Django User Database if authentication
     against Zimbra is successfull but no matching E-Mail in Django adress is found.
     the new user gets the attribute is_staff = True.
     
-    You can set your LDAP Servername in settuings using the variable LDAP_SERVER_NAME. E.g.:
+    You can set your LDAP Servername in settings using the variable LDAP_SERVER_NAME. E.g.:
     
-    LDAP_SERVER_NAME = 'mail.local.hudora.biz'
+    LDAP_SERVER_NAME = 'mail.hudora.biz'
     
     The code assumes the LDAP server allows "annonymous bind" (which is the default with Zimbra).
+    
+    This code is based in Django Ticket 2507 - http://code.djangoproject.com/attachment/ticket/2507
+    and code from Christian N Klein.
     """
-
-    # this code is based in Django Ticket 2507 - http://code.djangoproject.com/attachment/ticket/2507
-    # and code from Christian N Clein
-
+    
+    
     def authenticate(self, username=None, password=None):
         """Authenticate a user with password.
         
         Might also create the user in the Django User DB.
         """
         
-        servername = 'mail.local.hudora.biz'
+        servername = 'mail.hudora.biz'
         if hasattr(settings, 'LDAP_SERVER_NAME'):
             servername = settings.LDAP_SERVER_NAME
         lconn = ldap.open(servername)
@@ -108,15 +111,12 @@ class ZimbraBackend(django.contrib.auth.backends.ModelBackend):
         
         # get user DB from Django
         users = User.objects.filter(email=username)
-        if len(users) == 1:
-            # update django password
-            users[0].set_password(password)
-            users[0].save()
-            return users[0]
-        elif len(users) == 0:
+        # in case we get more than user back, we want a stable sort order.
+        users = sorted(users, cmp=lambda a, b: len(a.username)<len(b.username))
+        if len(users) == 0:
             # generate user from LDAP in Django
             user = User()
-            user.username = result_dict.get('uid')[0]
+            user.username = result_dict.get('uid')[0].replace('.', '')
             user.first_name = result_dict.get('givenName')[0]
             user.last_name = result_dict.get('sn')[0]
             user.email = result_dict.get('mail')[0]
@@ -124,5 +124,8 @@ class ZimbraBackend(django.contrib.auth.backends.ModelBackend):
             user.is_active = True
             user.set_password(password)
             user.save()
-            return user
-        return None
+        else:
+            user = users[0]
+            user.set_password(password)
+            user.save()
+        return user
