@@ -7,11 +7,7 @@ This acts like Django's ImageField but in addition can scale images on demand. S
 If the dimensions there are followed by an '!' this means the images should be cropped to exactly this size.
 Without this the images are scaled to fit in the given size without changing the aspect ratio of the image.
 
-Scaled versions of the images are generated on the fly using PIL. 
-
-In addition it also mangles the filename of the uploaded images to make sure they are unguessable and thus can
-put without authentication on a public webserver as long as directory listings ar prohibitet on that
-webserver.
+Scaled versions of the images are generated on the fly using PIL and then kept arround in the Filesystem. 
 
 Given a model like
 
@@ -48,27 +44,28 @@ Imagescaler instance beeing able to play some nifty tricks:
 >>> img.path_scaled().square_dimensions()
 (75, 76)
 
-Created August 2006 by Maximillian Dornseif. Consider it BSD licensed.
+Created August 2006 by Maximillian Dornseif. Updated in early 2009.
+Consider it BSD licensed.
 """
 
-import md5, time, os, urlparse
 import Image 
+import os
+import urlparse
 from django.conf import settings
+from django.db.models import ImageField
+from django.utils.functional import curry
 from django.utils.html import escape 
 from django.utils.safestring import mark_safe 
-from django.utils.functional import curry
-from django.dispatch import dispatcher
-from django.db.models import ImageField, signals
 
-_sizes = {'mini':    "23x40",
-          'thumb':   "50x200", 
+_sizes = {'mini': "23x40",
+          'thumb': "50x200", 
           'sidebar': "179x600",
-          'small':   "240x160",
-          'medium':  "480x320", 
-          'full':    "477x800",
-          'svga':    "800x600", 
-          'xvga':    "1024x768",
-          'square':  "75x75!"} 
+          'small': "240x160",
+          'medium': "480x320", 
+          'full': "477x800",
+          'svga': "800x600", 
+          'xvga': "1024x768",
+          'square': "75x75!"} 
 
 def _scaleImage(width, height, image):
     """
@@ -78,7 +75,7 @@ def _scaleImage(width, height, image):
     the bounding box.
     """
     #from http://simon.bofh.ms/cgi-bin/trac-django-projects.cgi/file/stuff/branches/magic-removal/image.py
-    lfactor = 1    
+    lfactor = 1
     width, height = int(width), int(height)
     (xsize, ysize) = image.size
     if xsize > width and ysize > height:
@@ -124,7 +121,7 @@ def _cropImage(width, height, image):
     res = res.crop((leftx, lefty, rightx, righty))
     return res
 
-class Imagescaler:
+class Imagescaler(object):
     """Class whose instances scale an image on the fly to desired properties.
     
     For each set of dimensions defined in _sizes imagescaler has a set of functions, e.g. for 'small':
@@ -135,22 +132,23 @@ class Imagescaler:
     o.small_tag() - return a complete image tag for use in XHTML
     
     >>> img.path_scaled().svga()
-    '/,/-/product/image/0e99d6be8ec0259df920c2d273d1ad6f.jpg/svga.jpeg'
+    '/,/-/product/image/0e99d6be8ec0259df920c2d273d1ad6f.jpg_svga.jpeg'
     >>> img.path_scaled().svga_path()
-    '/usr/local/web/media/,/-/product/image/0e99d6be8ec0259df920c2d273d1ad6f.jpg/svga.jpeg'
+    '/usr/local/web/media/,/-/product/image/0e99d6be8ec0259df920c2d273d1ad6f.jpg_svga.jpeg'
     >>> img.path_scaled().svga_dimensions()
     (328, 600)
     >>> img.path_scaled().svga_tag()
-    '<img src="/,/-/product/image/0e99d6be8ec0259df920c2d273d1ad6f.jpg/svga.jpeg" width="328" height="600" />'
+    '<img src="/,/-/product/image/0e99d6be8ec0259df920c2d273d1ad6f.jpg_svga.jpeg" width="328" height="600" />'
     """
     def __init__(self, field, obj):
         self.field = field
         self.parent_obj = obj
         self.original_image = getattr(self.parent_obj, self.field.attname)
-        self.original_image_path = os.path.join(settings.MEDIA_ROOT, self.original_image)
-        self.scaled_image_dir = os.path.join(settings.MEDIA_ROOT, ',', self.original_image)
+        self.original_image_path = os.path.join(settings.MEDIA_ROOT, str(self.original_image))
+        self.mangled_name = str(self.original_image) # md5.new('sehkr1tt-%s-%r-%r' % (str(self.original_image), time.time(), id(self))).hexdigest()
+        self.scaled_image_base = os.path.join(settings.MEDIA_ROOT, ',', self.mangled_name)
         self.broken_image = None
-        # if broken.gif exists we sendd that if there are any problems during scaling
+        # if broken.gif exists we send that if there are any problems during scaling
         if not os.path.exists(self.original_image_path):
             self.broken_image = os.path.join(settings.MEDIA_ROOT, 'broken.gif') 
         for size in _sizes:
@@ -158,28 +156,28 @@ class Imagescaler:
             setattr(self, '%s' % (size), curry(self.scaled_url, size))
             setattr(self, '%s_dimensions' % (size), curry(self.scaled_dimensions, size))
             setattr(self, '%s_tag' % (size), curry(self.scaled_tag, size))
-    
+
     def scaled_filename(self, size='thumb'):
         """Scales an image according to 'size' and returns the filename of the scaled image."""
         if self.broken_image:
             return self.broken_image
-        outpath = os.path.join(self.scaled_image_dir, size + '.jpeg')
+        outpath = "%s_%s.jpeg" % (self.scaled_image_base, size)
         if not os.path.exists(outpath):
             if size not in _sizes:
                 width, height = size.split('x')
             else:
                 width, height = _sizes[size].split('x')
-            if not os.path.exists(self.scaled_image_dir):
-                os.makedirs(self.scaled_image_dir)
             img = Image.open(self.original_image_path)
             if height.endswith('!'):
                 height = height.strip('!')
                 img = _cropImage(width, height, img)
             else:
                 img = _scaleImage(width, height, img)
+            if img.mode != "RGB":
+                img = img.convert("RGB")
             img.save(outpath, "JPEG")
         return outpath
-    
+
     def scaled_url(self, size='thumb'):
         """Scales an image according to 'size' and returns the URL of the scaled image."""
         if not self.original_image:
@@ -209,7 +207,10 @@ class Imagescaler:
         if not self.original_image:
             return ''
         ret = ['<img src="%s"' % escape(self.scaled_url(size))]
-        ret.append('width="%d" height="%d"' % self.scaled_dimensions(size))
+        try:
+            ret.append('width="%d" height="%d"' % self.scaled_dimensions(size))
+        except:
+            ret.append('width="50" height="50" alt="Fehler bei der Groessenberechnung" ')
         ret.extend(args)
         for key, val in kwargs.items():
             ret.append('%s="%s"' % (escape(key), escape(val)))
@@ -219,49 +220,21 @@ class Imagescaler:
 
 class ScalingImageField(ImageField):
     """This acts like Django's ImageField but in addition can scale images on demand by providing an
-    ImageScler object.
+    ImageScaler object.
     
     >>> img.path_scaled().svga()
     '/,/-/product/image/0e99d6be8ec0259df920c2d273d1ad6f.jpg/svga.jpeg'
     """
+
     def __init__(self, verbose_name=None, name=None, width_field=None, height_field=None, auto_rename=True,
                  **kwargs):
-        """Inits the ScalingImageField.
-        
-        By setting auto_rename=False you can keep the original filenames instead of generating pseudo-randomm
-        ones."""
-        self.auto_rename = auto_rename
+        """Inits the ScalingImageField."""
         super(ScalingImageField, self).__init__(verbose_name, name, width_field, height_field, **kwargs)
-   
-    def _save(self, instance=None):
-        """This is called whenever the model containing this field is saved. It renames the image
-            to something hard to guess."""
-        if not self.auto_rename:
-            return
-        if instance == None:
-            return
-        # generate hard to guess name
-        imagepath = getattr(instance, self.attname)
-        if not imagepath:
-            return
-        # generate unguessable name
-        newname = md5.new('sehkr1tt-%r-%r-%r-%r-%r' % (instance.__class__.__name__, self.name, time.time(),
-                           id(self), instance._get_pk_val())).hexdigest() + os.path.splitext(imagepath)[1]
-        newimagepath = os.path.join(os.path.split(imagepath)[0], newname)
-        if not os.path.exists(os.path.join(settings.MEDIA_ROOT, imagepath)):
-            return
-        os.rename(os.path.join(settings.MEDIA_ROOT, imagepath),
-                  os.path.join(settings.MEDIA_ROOT, newimagepath))
-        setattr(instance, self.attname, newimagepath)
-    
 
     def contribute_to_class(self, cls, name):
         """Adds field-related functions to the model."""
         super(ScalingImageField, self).contribute_to_class(cls, name)
         setattr(cls, '%s_scaled' % self.name, curry(Imagescaler, self))
-        #dispatcher.connect(_delete, signals.post_delete, sender=cls)
-        dispatcher.connect(self._save, signals.pre_save, sender=cls)
-   
 
     def get_internal_type(self):
-        return 'ImageField'
+        return 'FileField'
